@@ -60,6 +60,35 @@ defaults = dict(
     zmq_linger=1000,    # Wait one second before timing out on fedmsg-relay
     active=False,       # generally only true for fedmsg-logger
     persistent_store=None,  # an object.  See the fedmsg.replay module.
+    logging=dict(
+        version=1,
+        formatters=dict(
+            bare={
+                "datefmt": "%Y-%m-%d %H:%M:%S",
+                "format": "[%(asctime)s][%(name)10s %(levelname)7s] %(message)s"
+            },
+        ),
+        handlers=dict(
+            console={
+                "class": "logging.StreamHandler",
+                "formatter": "bare",
+                "level": "INFO",
+                "stream": "ext://sys.stdout",
+            }
+        ),
+        loggers=dict(
+            fedmsg={
+                "level": "INFO",
+                "propagate": False,
+                "handlers": ["console"],
+            },
+            moksha={
+                "level": "INFO",
+                "propagate": False,
+                "handlers": ["console"],
+            },
+        ),
+    ),
 )
 
 __cache = {}
