@@ -273,7 +273,7 @@ class FedMsgContext(object):
         msg = dict(
             topic=topic,
             msg=msg,
-            timestamp=time.time(),
+            timestamp=round(time.time(), 3),
             msg_id=str(year) + '-' + str(uuid.uuid4()),
             i=self._i,
             username=getpass.getuser(),
