@@ -17,7 +17,7 @@
 #
 # Authors:  Ralph Bean <rbean@redhat.com>
 #
-from fedmsg.text.base import BaseProcessor
+from fedmsg.meta.base import BaseProcessor
 
 
 class LoggerProcessor(BaseProcessor):
@@ -37,4 +37,8 @@ class LoggerProcessor(BaseProcessor):
             raise NotImplementedError
 
     def usernames(self, msg, **config):
-        return set([msg['username']])
+        if 'username' in msg:
+            return set([msg['username']])
+        else:
+            # *OLD* messages in datanommer's db don't have a username.
+            return set()
